==> crm-commom-vo-1.1.0.release.jar: com/biz/crm/nebular/sfa/worksign/resp/SfaExceptionReportRespVo.java <==
package com.biz.crm.nebular.sfa.worksign.resp;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 异常报备 返回vo
 *
 * @author ren.gang
 * @date 2020-11-23 15:00:38
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "异常报备 ")
@SaturnEntity(name = "SfaExceptionReportRespVo", description = "异常报备 返回vo")
public class SfaExceptionReportRespVo extends CrmExtVo {


    @ApiModelProperty("异常说明")
    @SaturnColumn(description = "异常说明")
    private String reportReason;

    @ApiModelProperty("人员姓名 人员姓名")
    @SaturnColumn(description = "人员姓名 人员姓名")
    private String realName;

    @ApiModelProperty("职位编码 职位编码")
    @SaturnColumn(description = "职位编码 职位编码")
    private String posCode;

    @ApiModelProperty("职位名称 职位名称")
    @SaturnColumn(description = "职位名称 职位名称")
    private String posName;

    @ApiModelProperty("所属组织编码 所属组织编码")
    @SaturnColumn(description = "所属组织编码 所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称 所属组织名称")
    @SaturnColumn(description = "所属组织名称 所属组织名称")
    private String orgName;

    @ApiModelProperty("申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    @SaturnColumn(description = "申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    private String applicationDate;

    @ApiModelProperty("开始时间 开始时间(yyyy-MM-dd HH)")
    @SaturnColumn(description = "开始时间 开始时间(yyyy-MM-dd HH)")
    private String beginTime;

    @ApiModelProperty("结束时间 结束时间(yyyy-MM-dd HH)")
    @SaturnColumn(description = "结束时间 结束时间(yyyy-MM-dd HH)")
    private String endTime;

    @ApiModelProperty("审批状态 审批状态")
    @SaturnColumn(description = "审批状态 审批状态")
    private String bpmStatus;

    @ApiModelProperty("附件列表json 附件列表json")
    @SaturnColumn(description = "附件列表json 附件列表json")
    private String attachmentListJson;
}

==> crm-commom-vo-1.1.3.release.jar: com/biz/crm/nebular/sfa/worksign/resp/SfaExceptionReportRespVo.java <==
package com.biz.crm.nebular.sfa.worksign.resp;

import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 异常报备 返回vo
 *
 * @author ren.gang
 * @date 2020-11-23 15:00:38
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "异常报备 ")
@SaturnEntity(name = "SfaExceptionReportRespVo", description = "异常报备 返回vo")
public class SfaExceptionReportRespVo extends CrmExtTenVo {


    @ApiModelProperty("异常说明")
    @SaturnColumn(description = "异常说明")
    private String reportReason;

    @ApiModelProperty("人员姓名 人员姓名")
    @SaturnColumn(description = "人员姓名 人员姓名")
    private String realName;

    @ApiModelProperty("职位编码 职位编码")
    @SaturnColumn(description = "职位编码 职位编码")
    private String posCode;

    @ApiModelProperty("职位名称 职位名称")
    @SaturnColumn(description = "职位名称 职位名称")
    private String posName;

    @ApiModelProperty("所属组织编码 所属组织编码")
    @SaturnColumn(description = "所属组织编码 所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称 所属组织名称")
    @SaturnColumn(description = "所属组织名称 所属组织名称")
    private String orgName;

    @ApiModelProperty("申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    @SaturnColumn(description = "申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    private String applicationDate;

    @ApiModelProperty("开始时间 开始时间(yyyy-MM-dd HH)")
    @SaturnColumn(description = "开始时间 开始时间(yyyy-MM-dd HH)")
    private String beginTime;

    @ApiModelProperty("结束时间 结束时间(yyyy-MM-dd HH)")
    @SaturnColumn(description = "结束时间 结束时间(yyyy-MM-dd HH)")
    private String endTime;

    @ApiModelProperty("审批状态 审批状态")
    @SaturnColumn(description = "审批状态 审批状态")
    private String bpmStatus;

    @ApiModelProperty("附件列表json 附件列表json")
    @SaturnColumn(description = "附件列表json 附件列表json")
    private String attachmentListJson;

    @ApiModelProperty("审核任务id")
    private String auditTaskId;
}
